pub struct UviBytes<T = Bytes> { /* fields omitted */ }
Encoder/Decoder of unsigned-varint, length-prefixed bytes
Limit the maximum allowed length of bytes.
Return the maximum allowed number of bytes to encode/decode.
The type of decoded frames.
The type of unrecoverable frame decoding errors. Read more
Attempts to decode a frame from the provided buffer of bytes. Read more
A default method available to be called when there are no more bytes
available to be read from the underlying I/O. Read more
Provides a Stream and Sink interface for reading and writing to this
Io object, using Decode and Encode to read and write the raw data. Read more
The type of items returned by decode
The type of decoding errors.
Decode an item from the src BytesMut into an item
Called when the input stream reaches EOF, signaling a last attempt to decode Read more
Returns the “default value” for a type. Read more
The type of items consumed by encode
The type of encoding errors.
Encodes an item into the BytesMut provided by dst.
Encodes a frame into the buffer provided. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.